// src/lib/get-casing-function.ts
function kebabCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[\s_]+/g, "-").toLowerCase();
}
function snakeCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1_$2").replace(/[\s-]+/g, "_").toLowerCase();
}
function getCasingFunction(casing) {
  return casing === "kebab" ? kebabCase : snakeCase;
}

// src/lib/logger.ts
var Logger = class {
  level;
  constructor(level = "info") {
    this.level = level;
  }
  setLevel(level) {
    this.level = level;
  }
  shouldLog(messageLevel) {
    const levels = ["error", "warn", "info", "debug"];
    return levels.indexOf(messageLevel) <= levels.indexOf(this.level);
  }
  log(level, ...messages) {
    if (this.shouldLog(level)) {
      const formattedMessage = messages.map((m) => typeof m === "string" ? m : JSON.stringify(m)).join(" ");
      if (level === "error") {
        console.error(formattedMessage);
      } else {
        console.log(formattedMessage);
      }
    }
  }
  error(err, ...messages) {
    const errorMessage = err instanceof Error ? err.message : err;
    this.log("error", errorMessage, ...messages);
  }
  warn(...messages) {
    this.log("warn", ...messages);
  }
  info(...messages) {
    this.log("info", ...messages);
  }
  debug(...messages) {
    this.log("debug", ...messages);
  }
};
var logger = new Logger();

// src/lib/convert-files.ts
import fs from "fs-extra";
import path from "path";
var TEMP_SUFFIX = "__tmp";
async function renameFilesAndFolders(directoryPath, paths, phase, casingFn) {
  const absoluteDirectoryPath = path.resolve(directoryPath);
  const renamedPaths = /* @__PURE__ */ new Set();
  for (const oldPath of paths) {
    const newPath = phase === "phase1" ? getNewPathPhaseOne(oldPath, casingFn) : getNewPathPhaseTwo(oldPath);
    logger.debug(`Move to ${newPath}`);
    if (newPath !== oldPath) {
      await moveFile(
        path.join(directoryPath, oldPath),
        path.join(directoryPath, newPath)
      );
      renamedPaths.add(path.dirname(oldPath));
    }
  }
  logger.info(`Removing empty directories after ${phase}`);
  await removeEmptyDirectories(absoluteDirectoryPath, renamedPaths);
}
async function removeEmptyDirectories(baseDirectory, renamedPaths) {
  const sortedPaths = Array.from(renamedPaths).sort(
    (a, b) => b.length - a.length
  );
  for (const relativePath of sortedPaths) {
    try {
      const absolutePath = path.join(baseDirectory, relativePath);
      const files = await fs.readdir(absolutePath);
      if (files.length === 0) {
        await fs.rmdir(absolutePath);
        logger.debug(`Removed empty directory: ${relativePath}`);
      }
    } catch (error) {
      logger.error(`Error processing directory ${relativePath}: ${error}`);
    }
  }
}
function getNewPathPhaseOne(filePath, casingFn) {
  const segments = filePath.split(path.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      return convertFileName(segment, casingFn);
    }
    return convertSegment(segment, casingFn);
  });
  return path.join(...newSegments);
}
function convertFileName(fileName, casingFn) {
  const ext = path.extname(fileName);
  const baseName = path.basename(fileName, ext);
  if (
    /** Preserve Next.js _app.tsx etc */
    baseName.startsWith("_") || /** Preserve files like README or LICENSE */
    baseName === baseName.toUpperCase()
  ) {
    return fileName;
  }
  const convertedBaseName = convertSegment(baseName, casingFn);
  return convertedBaseName + ext;
}
function convertSegment(segment, casingFn) {
  if (segment.startsWith("[")) {
    return segment;
  }
  if (segment.startsWith("_")) {
    return segment;
  }
  const converted = casingFn(segment);
  if (converted === segment) {
    return converted;
  } else if (converted.toLowerCase() === segment.toLowerCase()) {
    return converted + TEMP_SUFFIX;
  } else {
    return converted;
  }
}
function getNewPathPhaseTwo(filePath) {
  const segments = filePath.split(path.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      const ext = path.extname(segment);
      const baseName = path.basename(segment, ext);
      if (baseName.endsWith(TEMP_SUFFIX)) {
        const newBaseName = baseName.slice(0, -TEMP_SUFFIX.length).toLowerCase();
        logger.debug(
          `Phase 2 conversion: ${baseName}${ext} -> ${newBaseName}${ext}`
        );
        return newBaseName + ext;
      }
    } else if (segment.endsWith(TEMP_SUFFIX)) {
      const newSegment = segment.slice(0, -TEMP_SUFFIX.length).toLowerCase();
      logger.debug(`Phase 2 conversion: ${segment} -> ${newSegment}`);
      return newSegment;
    } else if (segment.includes(TEMP_SUFFIX)) {
      logger.warn(`Unexpected TEMP_SUFFIX in middle of segment: ${segment}`);
    }
    return segment;
  });
  return path.join(...newSegments);
}
async function moveFile(oldPath, newPath) {
  try {
    await fs.ensureDir(path.dirname(newPath));
    await fs.move(oldPath, newPath, { overwrite: false });
    logger.debug(`Moved: ${oldPath} -> ${newPath}`);
  } catch (error) {
    logger.error(
      `Failed to move file: ${oldPath} -> ${newPath}. Error: ${error}`
    );
  }
}

export {
  getCasingFunction,
  logger,
  renameFilesAndFolders,
  convertFileName,
  convertSegment
};
