#!/usr/bin/env node
import {
  getCasingFunction,
  logger,
  renameFilesAndFolders
} from "./chunk-NYHPEC3F.mjs";

// src/main.ts
import meow from "meow";
import sourceMaps from "source-map-support";

// src/lib/commit-changes.ts
import simpleGit from "simple-git";
var git = simpleGit();
async function commitChanges(message) {
  await git.add("./*");
  await git.commit(message);
}

// src/lib/get-files-to-process.ts
import { globby } from "globby";
var alwaysIgnorePatterns = [
  "node_modules/",
  ".git/",
  ".github/",
  "package-lock.json",
  "npm-shrinkwrap.json",
  "pnpm-lock.yaml",
  "pnpm-workspace.yaml"
];
async function getFilesToProcess(ignorePatterns = []) {
  const paths = await globby(["**/*"], {
    gitignore: true,
    ignore: [...alwaysIgnorePatterns, ...ignorePatterns]
  });
  return paths;
}

// src/lib/get-gitignore-patterns.ts
import fs from "fs-extra";
import path from "node:path";
async function getGitignorePatterns(directoryPath) {
  const cwdGitignorePath = path.join(process.cwd(), ".gitignore");
  const directoryGitignorePath = path.join(directoryPath, ".gitignore");
  let gitignorePath;
  if (await fs.pathExists(cwdGitignorePath)) {
    gitignorePath = cwdGitignorePath;
  } else if (await fs.pathExists(directoryGitignorePath)) {
    gitignorePath = directoryGitignorePath;
  } else {
    logger.error(
      ".gitignore file not found in both CWD and specified directory."
    );
    process.exit(1);
  }
  return fs.readFileSync(gitignorePath, "utf-8").split("\n").map((line) => line.trim()).filter((line) => line && !line.startsWith("#"));
}

// src/lib/run-codemod.ts
import Runner from "jscodeshift/src/Runner.js";
import path2 from "node:path";
import { fileURLToPath } from "node:url";
async function runCodemod(filePaths, casingType) {
  logger.debug("Running codemod");
  const codeExtensions = ["ts", "tsx", "js", "jsx", "mjs", "cjs"];
  const __filename2 = fileURLToPath(import.meta.url);
  const __dirname2 = path2.dirname(__filename2);
  const codemodPath = path2.resolve(
    __dirname2,
    casingType === "kebab" ? "./codemods/convert-import-export-kebab.cjs" : "./codemods/convert-import-export-snake.cjs"
  );
  logger.debug("Codemod path:", codemodPath);
  const result = await Runner.run(codemodPath, filePaths, {
    parser: "tsx",
    // verbose: 1,
    extensions: codeExtensions.join(","),
    runInBand: true
  });
  return result;
}

// src/main.ts
sourceMaps.install();
var cli = meow(
  `
  Usage
    $ npx convert-codebase-casing <directory>

  Options
    --help, -h             Show help text
    --log-level, -l        Log level: 'error', 'warn', 'info', or 'debug' (default: 'info')
    --casing, -c           Casing type: 'kebab' or 'snake' (default: 'kebab')

  Examples
    $ npx convert-codebase-casing ./src
    $ npx convert-codebase-casing ./src --casing snake
    $ npx convert-codebase-casing ./src --log-level debug
`,
  {
    importMeta: import.meta,
    flags: {
      help: {
        type: "boolean",
        shortFlag: "h"
      },
      casing: {
        type: "string",
        shortFlag: "c",
        choices: ["kebab", "snake"],
        default: "kebab"
      },
      logLevel: {
        type: "string",
        shortFlag: "l",
        default: "info"
      }
    }
  }
);
logger.setLevel(cli.flags.logLevel);
async function run() {
  const directoryPath = cli.input[0];
  if (!directoryPath) {
    logger.error("Please specify a directory path.");
    process.exit(1);
  }
  const ignorePatterns = await getGitignorePatterns(directoryPath);
  const casingType = cli.flags.casing;
  if (casingType !== "kebab" && casingType !== "snake") {
    logger.error("Error: Invalid casing type. Use 'kebab' or 'snake'.");
    process.exit(1);
  }
  const casingFn = getCasingFunction(casingType);
  {
    logger.info("Rename phase 1/2...");
    const filePaths = await getFilesToProcess(ignorePatterns);
    logger.info(`Found ${filePaths.length} files to process`);
    await renameFilesAndFolders(directoryPath, filePaths, "phase1", casingFn);
    logger.info("Commit changes");
    await commitChanges("Rename files and folders phase 1/2");
  }
  {
    logger.info("Rename phase 2/2...");
    const filePaths = await getFilesToProcess(ignorePatterns);
    logger.info(`Found ${filePaths.length} files to process`);
    await renameFilesAndFolders(directoryPath, filePaths, "phase2", casingFn);
    logger.info("Commit changes");
    await commitChanges("Rename files and folders phase 2/2");
  }
  {
    logger.info("Running codemod to update import/export statements");
    const filePaths = await getFilesToProcess(ignorePatterns);
    await runCodemod(filePaths, casingType);
    logger.info("Commit changes");
    await commitChanges("Update import and export statements");
  }
  logger.info("Conversion completed!");
}
run().catch((err) => {
  logger.error(err);
  process.exit(1);
});
